@@ -5,12 +5,13 @@ use warnings;
 package Dancer2::Plugin::ParamKeywords;
 use Dancer2::Plugin;
 
-our $VERSION = 'v0.1.3';
+our $VERSION = 'v0.1.4';
 
 foreach my $source ( qw( route query body ) ) {
     register "$source\_param" => sub {
         my ($dsl, $param)  = @_;
-        %{ $dsl->app->request->params($source) || {} }{$param};
+        my $hash = $dsl->app->request->params($source) || {};
+        $hash->{$param};
     };
     
     register "$source\_params" => sub {
@@ -58,7 +59,7 @@ Dancer2::Plugin::ParamKeywords - Sugar for the params() keyword
 
 =head1 VERSION
 
-version v0.1.3
+version v0.1.4
 
 =head1 SYNOPSIS
 
